import chalk from 'chalk';
import isBrowser from 'is-browser';

const COLORS = {
  blue: ['#1E88E5', '#90CAF9'],
  brown: ['#6D4C41', '#D7CCC8'],
  gray: ['#212121', '#BDBDBD'],
  green: ['#388E3C', '#A5D6A7'],
  red: ['#E53935', '#EF9A9A'],
  orange: ['#F4511E', '#FFAB91'],
  purple: ['#8E24AA', '#E1BEE7'],
  yellow: ['#FFD600', '#FFF59D']
};

const print = Object.entries(COLORS).reduce(
  (api, [name, [bg, text]]) => ({
    [name]: api.makeColor(name, bg, text),
    ...api
  }),
  {
    makeColor: (name, bg, text) => (
      shortLabel,
      longerMessage,
      optionalSuffix = ''
    ) => {
      return isBrowser || process
        ? console.log(
            `%c${shortLabel}%c${longerMessage}%c${optionalSuffix}`,
            `background-color: ${bg}; color: #fff; padding: 2px 4px; font-weight: bold;`,
            `background-color: ${text}; color: #000; padding: 2px 4px;`,
            optionalSuffix === ''
              ? ''
              : `background-color: ${bg}; color: #fff; padding: 2px 4px; font-weight: bold;`
          )
        : console.log(
            `${chalk.bgHex(bg)(` ${shortLabel} `)}  ${chalk.hex(text)(
              longerMessage
            )}  ${
              optionalSuffix ? chalk.bgHex(bg).bold(` ${optionalSuffix} `) : ''
            }`
          );
    }
  }
);

export default print;
